@@ -112,7 +112,7 @@ from arjuna.tpi.engine.data_markup import *
 from arjuna.tpi.error import *
 
 from arjuna.tpi.data.record import *
-from arjuna.tpi.data.generator import Random, Locales, generator, composite, composer
+from arjuna.tpi.data.generator import Random, generator, composite, composer
 from arjuna.tpi.data.entity import data_entity
 
 from arjuna.tpi.guiauto.meta.locator import GuiWidgetDefinition
