@@ -31,7 +31,10 @@ _RAW_OPTION_LEVELS = {
         "CONF_PROJECT_FILE",
         "CONF_PROJECT_LOCAL_FILE",
         "TESTS_DIR",
-        "HOOKS_DIR",
+        "HOOKS_PACKAGE",
+        "HOOKS_CONFIG_PACKAGE",
+        "HOOKS_ENTITY_PACKAGE",
+        "HOOKS_RESOURCE_PACKAGE",
         "REPORTS_DIR",
         "REPORT_DIR",
         "REPORT_XML_DIR",
@@ -89,6 +92,7 @@ _RAW_OPTION_LEVELS = {
         "HTTP_PROXY_ENABLED",
         "HTTP_PROXY_HOST",
         "HTTP_PROXY_PORT",
+        "SOCKET_TIMEOUT"
     },
 
     ConfigStage.REFERENCE: {
