@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -18,7 +18,9 @@
 import abc
 from arjuna.core.error import WaitableError, _GuiWidgetPresentError
 from arjuna.tpi.error import GuiWidgetNotFoundError
+from arjuna import track
 
+@track("debug")
 class ElementFinder:
     def __init__(self, container): #, obj_name=""):
         self.__container = container
@@ -51,7 +53,7 @@ class ElementFinder:
             raise _GuiWidgetPresentError(*wmd.locators)
 
     def find(self, dispatcher_call, wmd, context="ELEMENT"):
-        from arjuna import log_trace
+        from arjuna import log_trace, log_debug
         log_trace("Finding with wmd: {}".format(str(wmd)))
         from arjuna import Arjuna
         found = False
@@ -62,6 +64,8 @@ class ElementFinder:
             if "POINT" in {l.ltype.name for l in locators}:
                 raise ConditionException("With.POINT can be used only with GuiElement.")
 
+        # Prepare Relations dict
+
         we = None
         for locator in locators:
             try:
@@ -75,13 +79,16 @@ class ElementFinder:
                     if locator.ltype.name == "XPATH":
                         if not lvalue.startswith("."):
                             lvalue = "." + lvalue
-                    size, dispatcher = dispatcher_call(locator.ltype.name, lvalue)
+                    log_debug("Trying out locator {} with value {}".format(locator.ltype.name, lvalue))
+                    size, dispatcher = dispatcher_call(locator.ltype.name, lvalue, relations=wmd.meta.relations, filters=wmd.meta.filters)
                 return locator.ltype.name, locator.lvalue, size, dispatcher
             except WaitableError as e:
+                log_debug("Waitable exception raised.")
                 we = e
             except Exception as f:
+                log_debug("Non-Waitable exception raised: {}: {}".format(f.__class__.__name__, str(f)))
                 raise f
             else:
                 we = None
         if not found:
-            raise GuiWidgetNotFoundError(*wmd.locators, container=self.__container)
\ No newline at end of file
+            raise GuiWidgetNotFoundError(*wmd.locators, relations=wmd.meta.relations, filters=wmd.meta.filters, container=self.__container)
\ No newline at end of file
