@@ -194,4 +194,5 @@ class ContextualDataReference(metaclass=abc.ABCMeta):
 
     def as_json(self):
         from arjuna import Json, Http
-        return Json.from_str(Http.content.json(self.named_values).content)
\ No newline at end of file
+        from arjuna.core.fmt import arj_convert
+        return Json.from_object(arj_convert(self.named_values))
\ No newline at end of file
