@@ -540,4 +540,14 @@ class axes:
         self.__axes.append(_Axis(DomDirection.RIGHT, node))
         return self
 
+class NotFound:
+    '''
+    To differentiate a not found object from Python's None.
+
+    Always evalutes to False in a boolean context.
+    '''
+    
+    def __bool__(self):
+        return False
+
 NetworkPacketInfo = namedtuple("NetworkPacketInfo", "label request response sub_network_packets")
\ No newline at end of file
