@@ -23,8 +23,8 @@ import json
 import copy
 import abc
 from arjuna.tpi.helper.arjtype import _ArDict
-from jsonpath_rw import jsonpath
-from jsonpath_rw_ext import parse
+from jsonpath_ng import jsonpath, parse
+#from jsonpath_rw_ext import parse
 from json.decoder import JSONDecodeError
 from genson import SchemaBuilder
 from typing import Any
@@ -85,7 +85,7 @@ class JsonList(JsonElement):
         Note:
             Supports indexing just like a Python list.
 
-            Also supports == operator. Right operand can be a Python list or a `JsonList` object.
+            Also supports == operator. Right operand can be a Python list or a `JsonList` or a `YamlList` object.
     '''
 
     def __init__(self, pylist: list):
@@ -97,6 +97,9 @@ class JsonList(JsonElement):
     def __getitem__(self, index):
         return Json.from_object(self.__list[index], allow_any=True)
 
+    def __delitem__(self, index):
+        del self.store[key]
+
     def __len__(self):
         return len(self.__list)
 
@@ -114,6 +117,24 @@ class JsonList(JsonElement):
         '''
         return copy.deepcopy(self.__list)
 
+    def pop(self, index=-1):
+        '''
+            Remove and return item at index (default last).
+        '''
+        return Json.from_object(self.__list.pop(index), allow_any=True)
+
+    def extend(self, iterable):
+        '''
+            Extend JsonList by appending elements from the iterable.
+        '''
+        self.__list.extend(iterable)
+
+    def append(self, object):
+        '''
+            Append object to the end of the JsonList.
+        '''
+        self.__list.append(object)
+
     def __str__(self):
         return str(self.__list)
 
@@ -121,9 +142,10 @@ class JsonList(JsonElement):
         return len(self.__list)
 
     def __eq__(self, other):
+        from arjuna.tpi.parser.yaml import YamlList
         if type(other) is list:
             pass
-        elif type(other) is JsonList:
+        elif type(other) is JsonList or type(other) is YamlList:
             other = other.raw_object
         elif other is None:
             return False
@@ -147,14 +169,30 @@ class JsonDict(_ArDict, JsonElement):
         Note:
             Supports dictionary methods as well as **.** access for key.
 
-            Also supports == operator. Right operand can be a Python dict or a `JsonDict` object.
-
+            Also supports == operator. Right operand can be a Python dict or a `JsonDict` or a `YamlDict` or any custom DataEntity object.
     '''
 
     def __init__(self, pydict: dict=None):
+        self.__dict = pydict
         _ArDict.__init__(self, pydict)
         JsonElement.__init__(self, self.store)
 
+    def __str__(self):
+        return str(self.store)
+
+    __repr__ = __str__
+
+    def __delitem__(self, key):
+        del self.store[key]
+
+    def __getattr__(self, attr):
+        try:
+            val = self.__dict[attr]
+        except AttributeError:
+            raise AttributeError(f"No attribute/key with name {attr}.")
+        else:
+            return Json.from_object(val, allow_any=True)
+
     @property
     def size(self):
         '''
@@ -214,7 +252,7 @@ class JsonDict(_ArDict, JsonElement):
         validator = Draft7Validator(schema)
         errors = []
         for error in sorted(validator.iter_errors(self.store), key=str):
-            errors.append("Key >>{}<<: {}".format(".".join(error.path), error.message))
+            errors.append("Key >>{}<<: {}".format(".".join([str(i) for i in error.path]), error.message))
         if errors:
             return False, errors
         else:
@@ -248,7 +286,7 @@ class JsonDict(_ArDict, JsonElement):
         if not matched:
             raise AssertionError("JsonDict does not match schema. Found the following errors. {}".format(". ".join(errors)))
 
-    def assert_match(self, jobj, *, msg, ignore_keys=None):
+    def assert_match(self, jobj, *, msg, ignore=None):
         '''
             Assert that this JsonDict matches the provided object.
 
@@ -257,23 +295,45 @@ class JsonDict(_ArDict, JsonElement):
 
             Keyword Args:
                 msg: Purpose of this assertion.
-                ignore_keys: Keys to be ignored while matching
+                ignore: jpath to be ignored while matching
         '''
-        if type(jobj) is dict:
-            jobj = JsonDict(jobj)
-        elif type(jobj) is JsonDict:
-            pass
-        else:
+        if type(jobj) not in {dict, JsonDict}:
             raise Exception("JsonDict.assert_match expected_dict argument should be a dictionary or a JsonDict object.")
-        if ignore_keys is None:
-            ignore_keys = set()
-        elif type(ignore_keys) in {set, dict, list, tuple}:
-            ignore_keys = set([i.lower() for i in ignore_keys])
+
+        # New logic based on content update to support japths instead of just keys to ignore.
+        if ignore is None:
+            ignore = set()
+        elif type(ignore) in {set, dict, list, tuple}:
+            ignore = set([i for i in ignore])
         else:
-            ignore_keys = {str(ignore_keys).lower()}
-        for k,v in self.items():
-            if k.lower() not in ignore_keys:
-                self.asserter.assert_equal(Json.from_object(v, allow_any=True), jobj[k], msg=msg)
+            ignore = {str(ignore)}
+
+        from copy import deepcopy
+        raw_obj = deepcopy(self.raw_object)
+        if type(jobj) is JsonDict:
+            jobj = deepcopy(jobj.raw_object)
+        else:
+            jobj = deepcopy(jobj)
+
+        for i in ignore:
+            expr = parse(i)
+            raw_obj = expr.update(raw_obj, "__IGNORE__")
+            jobj = expr.update(jobj, "__IGNORE__")
+
+        for k,v in raw_obj.items():
+            if k in jobj:
+                self.asserter.assert_equal(Json.from_object(v, allow_any=True), jobj[k], msg=msg + f" Verify key: {k}")
+            else:
+                if v == "__IGNORE__":
+                    continue
+                self.asserter.fail(msg=f"Extra key >>{k}<< with value >>{v}<< found in Json matching.")
+
+        for k,v in jobj.items():
+            if k not in raw_obj:
+                if v == "__IGNORE__":
+                    continue
+                self.asserter.fail(msg=f"Missing key >>{k}<< in target Json Element matching. Expected value >>{v}<<.")
+
 
     @property
     def schema(self) -> 'JsonSchema':
@@ -283,10 +343,15 @@ class JsonDict(_ArDict, JsonElement):
         return Json.extract_schema(self)
 
     def __eq__(self, other):
+        from arjuna.tpi.parser.yaml import YamlDict
+        from arjuna.tpi.data.entity import _DataEntity
+
         if type(other) is dict:
             pass
-        elif type(other) is JsonDict:
+        elif type(other) is JsonDict or type(other) is YamlDict:
             other = other.raw_object
+        elif isinstance(other, _DataEntity):
+            other = other.as_dict()
         elif other is None:
             return False
         else:
@@ -550,7 +615,7 @@ class Json:
                 Arjuna's `JsonDict` object
         '''
 
-        return JsonDict(d)
+        return JsonDict(map)
 
     @classmethod
     def from_iter(cls, iter) -> JsonList:
