@@ -20,7 +20,7 @@ import re
 
 from arjuna.core.utils import data_utils
 from arjuna.core.types import constants
-
+from arjuna.tpi.data.entity import _DataEntity
 
 class TextFile:
     '''
@@ -245,17 +245,160 @@ from arjuna.tpi.engine.asserter import AsserterMixIn
 
 class Text(str, AsserterMixIn):
     '''
-    Provides factory methods for dealing with reading text file content in various forms.
+        Arjuna representation of a String.
+        Provides factory methods for dealing with reading text file content in various forms.
+
+        Arguments:
+            text: Input string. If a non-string object is provided it str(text) is called.
+            fargs: Arbitrary positional arguments for formatting the string.
+
+        Keyword Arguments:
+            fnargs: Arbitrary named arguments (keworg arguments) for formatting the string.
     '''
-    def __init__(self, text):
+    def __init__(self, text, *fargs, **fnargs):
         str.__init__(text)
         AsserterMixIn.__init__(self)
         self.__content = text
+        self.__do_eval = False
+        if type(self.__content) is not str:
+            self.__do_eval = True
+            self.__content = str(self.__content)
+        self.__fargs = fargs
+        self.__fnargs = fnargs
+        if self.__fargs or self.__fnargs:
+            self.format(*self.__fargs, **self.__fnargs)
+
+    def format(self, *fargs, **fnargs):
+        '''
+            Format the string using provided named and keyword arguments.
+
+            Positional arguments are used to format $$ placeholders as per the order in which they are found.
+
+            Keyword/named arguments are used to format $<name>$ placeholders. Order does not matter.
+
+            Supports C/L/R queries as names of placeholders.
+
+            The provided features are very advanced. Refer Arjuna documentation for use cases and examples.
+
+            Arguments:
+                fargs: Arbitrary positional arguments for formatting the string.
+
+            Keyword Arguments:
+                fnargs: Arbitrary named arguments (keworg arguments) for formatting the string.
+        '''
+
+        target = self.__content
+
+        def get_global_value(in_str):
+            from arjuna import C, L, R
+            gtype, query = in_str.split(".", 1)
+            gtype = gtype.upper()
+            return locals()[gtype](query)
+
+        pos_pattern = r"(\$\s*\$)"
+        named_pattern = r"\$(\s*[\w\.]+?\s*)\$"
+        fmt_target = target.replace("{", "__LB__").replace("}", "__RB__")
+
+        # Find params
+        pos_matches = re.findall(pos_pattern, fmt_target)
+        named_matches = re.findall(named_pattern, fmt_target)
+
+        if pos_matches and named_matches:
+            for match in named_matches:
+                match = match.lower().strip()
+                if not match.startswith("c.") and not match.startswith("l.") and not match.startswith("r."):
+                    raise Exception("You can not use positional $$ placeholders and named $<name>$ placholders together in a withx locator definition (except those with C./L./R. prefixes to fetch global values. Wrong withx definition: " + target)
+
+        if pos_matches:
+            if not fargs:
+                fargs = tuple()    
+            if len(pos_matches) != len(fargs):
+                raise Exception("Number of positional arguments supplied to format withx locator do not match number of $$ placeholders. Placeholders: {}. Positional args: {}. Wrong usage of withx locator: {}".format(len(pos_matches), fargs, target))
+
+            for i,match in enumerate(pos_matches):
+                fmt_target = fmt_target.replace(match, "{}")
+
+            fmt_target = fmt_target.format(*fargs)
+
+        def get_value_from_container(name, *, container=None):
+            if container is None:
+                parts = name.split(".", 1)
+                if len(parts) == 1:
+                    # It is reference directly to an object and if present could have been resolved before this logic hits.
+                    return "__NOTFOUND"
+                container, name = parts
+
+            name_parts = re.split(r'([\.\[])', name, 1) # Will return single element list or 3 part list: name, delim, rest
+            if len(name_parts) == 1:
+                name, delim, rest = name, "", ""
+            else:
+                name, delim, rest = name_parts
+
+            try:
+                container = fnargs[container]
+                if type(container) is dict:
+                    first_obj = container[name]
+                elif isinstance(type(container), _DataEntity):
+                    first_obj = getattr(container, name)
+                if delim == "":
+                    return first_obj
+                else:
+                    return eval(f"first_obj{delim}{rest}")
+            except Exception as e:
+                return "__NOTFOUND"                 
+            
+        for match in named_matches:
+            names_set = None
+            target = "${}$".format(match)
+            processed_name = match.lower().strip()
+            repl_value = None
+            if processed_name.startswith("c.") or processed_name.startswith("l.") or processed_name.startswith("r."):
+                repl_value = get_global_value(processed_name)
+            elif processed_name.startswith("data."):
+                processed_name = processed_name.split(".")[1]
+                if 'data' in fnargs:
+                    temp_val = get_value_from_container(processed_name, container="data")
+                    if temp_val == "__NOTFOUND":
+                        continue
+                    else:
+                        repl_value = temp_val
+                else:
+                    continue
+            else:
+                if processed_name not in fnargs:
+                    # Try a container and dynamic logic like a.b.c or a.b[3]
+                    temp_val = get_value_from_container(processed_name)
+                    if temp_val != "__NOTFOUND":
+                        repl_value = temp_val
+                    else:
+                        if 'data' in fnargs:
+                            temp_val = get_value_from_container(processed_name, container="data")
+                            if temp_val == "__NOTFOUND":
+                                continue
+                            else:
+                                repl_value = temp_val
+                        else:
+                            continue
+                else:
+                    repl_value = fnargs[processed_name]
+
+            fmt_target = fmt_target.replace(target, str(repl_value))
+
+        fmt_target = fmt_target.replace("__LB__", "{").replace("__RB__", "}")
+        if self._eval:
+            fmt_target = eval(fmt_target)
+
+        self.__content = fmt_target
+        return self.__content
 
     @property
     def content(self):
         return self.__content
 
+    @property
+    def _eval(self):
+        return self.__do_eval
+
     def assert_contains(self, sub_str, *, msg):
         self.asserter.assert_true(sub_str in self.content, msg="Sub string {} not found in {}. ".format(sub_str, self.content) + msg)
 
@@ -283,7 +426,10 @@ class Text(str, AsserterMixIn):
         return self.content
 
     def __eq__(self, other):
-        return self.content == other
+        if isinstance(other, Text):
+            return self.content == other.content
+        else:
+            return self.content == other
 
     @classmethod
     def file_content(cls, fpath) -> str:
